==> scorched-0.12.tar.gz: scorched-0.12/setup.py <==
from __future__ import unicode_literals
from setuptools import find_packages
from setuptools import setup

import os


version = '0.12'

here = os.path.abspath(os.path.dirname(__file__))
README = open(os.path.join(here, 'README.rst')).read()
CHANGES = open(os.path.join(here, 'CHANGES.rst')).read()


setup(name='scorched',
      version=version,
      description="solr search orm like query builder",
      long_description=README + '\n\n' + CHANGES,
      classifiers=[
                  'Environment :: Console',
                  'Environment :: Web Environment',
                  'Intended Audience :: Developers',
                  'License :: OSI Approved :: MIT License',
                  'Operating System :: MacOS :: MacOS X',
                  'Operating System :: Microsoft :: Windows',
                  'Operating System :: POSIX',
                  'Programming Language :: Python :: 2',
                  'Programming Language :: Python :: 2.7',
                  'Programming Language :: Python :: 3',
                  'Programming Language :: Python :: 3.4',
                  'Programming Language :: Python :: 3.5',
      ],
      keywords='solr tow sunburnt offspring',
      author='(Josip Delic) Lugensa GmbH',
      author_email='info@lugensa.com',
      url='http://www.lugensa.com',
      license='MIT',
      packages=find_packages(exclude=['ez_setup', 'examples', 'tests']),
      include_package_data=True,
      zip_safe=False,
      install_requires=[
          "setuptools",
          "requests",
          "pytz",
      ],
      extras_require={
          'test': ["nose", "coverage", "mock", ],
      },
      test_suite='scorched.tests',
      setup_requires=["setuptools_git"],
      )

==> scorched-0.13.0.tar.gz: scorched-0.13.0/setup.py <==
from __future__ import unicode_literals
from setuptools import find_packages
from setuptools import setup

import os


version = '0.13.0'

here = os.path.abspath(os.path.dirname(__file__))
README = open(os.path.join(here, 'README.rst')).read()
CHANGES = open(os.path.join(here, 'CHANGES.rst')).read()


setup(name='scorched',
      version=version,
      description="solr search orm like query builder",
      long_description=README + '\n\n' + CHANGES,
      classifiers=[
                  'Environment :: Console',
                  'Environment :: Web Environment',
                  'Intended Audience :: Developers',
                  'License :: OSI Approved :: MIT License',
                  'Operating System :: MacOS :: MacOS X',
                  'Operating System :: Microsoft :: Windows',
                  'Operating System :: POSIX',
                  'Programming Language :: Python :: 2',
                  'Programming Language :: Python :: 2.7',
                  'Programming Language :: Python :: 3',
                  'Programming Language :: Python :: 3.4',
                  'Programming Language :: Python :: 3.5',
                  'Programming Language :: Python :: 3.6',
                  'Programming Language :: Python :: 3.7',
                  'Programming Language :: Python :: 3.8',
      ],
      keywords='solr tow sunburnt offspring',
      author='(Josip Delic) Lugensa GmbH',
      author_email='info@lugensa.com',
      url='http://www.lugensa.com',
      license='MIT',
      packages=find_packages(exclude=['ez_setup', 'examples', 'tests']),
      include_package_data=True,
      zip_safe=False,
      install_requires=[
          "setuptools",
          "requests",
          "pytz",
      ],
      extras_require={
          'test': ["nose", "coverage", "mock;python_version<'3'"],
      },
      test_suite='scorched.tests',
      setup_requires=["setuptools_git"],
      )
